<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="+45"/>
        <source>&amp;About</source>
        <translation type="unfinished">&amp;O</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Main developers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+14"/>
        <source>A&amp;uthors</source>
        <translation type="unfinished">&amp;Avtorji</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Translation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Czech</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Slovenian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>French</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Turkish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Italian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Traditional Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arabic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Russian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hebrew</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Logo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Coordinating</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Testing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Thanks To</source>
        <translation type="unfinished">&amp;Zahvale gredo</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Licence Agreement</source>
        <translation type="unfinished">&amp;Licenčna pogodba</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>About</source>
        <translation type="unfinished">O</translation>
    </message>
    <message>
        <location line="-83"/>
        <source>This is the Stopmotion application for creating stop motion animations.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+30"/>
        <source>German</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Portuguese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Spanish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Swedish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-23"/>
        <source>Contributors</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeviceTab</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="+64"/>
        <location line="+293"/>
        <source>Below you can set which device Stopmotion should use for grabbing images and displaying video.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-291"/>
        <location line="+293"/>
        <source>You can select from the auto-detected devices below or add devices yourself. It is not recommended to use devices which is not auto-detected, but feel free to do it if you are an advanced user.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-290"/>
        <location line="+293"/>
        <source>The selected device is recognized as &lt;b&gt;$VIDEODEVICE&lt;/b&gt; under Video Import.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-287"/>
        <location line="+291"/>
        <source>Name</source>
        <translation type="unfinished">Ime</translation>
    </message>
    <message>
        <location line="-291"/>
        <location line="+291"/>
        <source>Description</source>
        <translation type="unfinished">Opis</translation>
    </message>
    <message>
        <location line="-277"/>
        <location line="+280"/>
        <source>&amp;Add</source>
        <translation type="unfinished">&amp;Dodaj</translation>
    </message>
    <message>
        <location line="-276"/>
        <location line="+277"/>
        <source>&amp;Remove</source>
        <translation type="unfinished">&amp;Odstrani</translation>
    </message>
    <message>
        <location line="-274"/>
        <location line="+275"/>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Uredi</translation>
    </message>
    <message>
        <location line="-271"/>
        <location line="+274"/>
        <source>Video device settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-265"/>
        <location line="+266"/>
        <source>Video Device ($VIDEODEVICE): </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-218"/>
        <source>device</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExportTab</name>
    <message>
        <source>&lt;p&gt;Below you can set which program/process stopmotion should use for encoding the currently active project to a video file.&lt;/p&gt;&lt;p&gt;You can use $IMAGEPATH to represent the image path (absolute path to the directory where the images can be found). You should always use &lt;b&gt;$VIDEOFILE&lt;/b&gt; to represent the output file (the videofile generated by the encoder) in the &lt;b&gt;command line&lt;/b&gt;. This is independent of how you decides to select it (select it for each export or have a default file).&lt;br&gt;&lt;/p&gt;&lt;p&gt; Example with mencoder (converting jpg to mpeg1): &lt;br&gt;mencoder mf://$IMAGEPATH/*.jpg -mf w=640:h=480:fps=12:type=jpg -ovc lavc -lavcopts vcodec=mpeg1video -oac copy -o $VIDEOFILE &lt;br&gt;</source>
        <translation type="obsolete">&lt;p&gt;Spodaj lahko nastavite katere programe/procese naj stopmotion uporablja za kodiranje trenutno aktivnega projekta v video datoteko.&lt;/p&gt;&lt;p&gt;Lahko uporabite $IMAGEPATH kot pot do slikovne datoteke (absolutna pot do datoteke kjer so shranjene slike). Vedno uporabite &lt;b&gt;$VIDEOFILE&lt;/b&gt; kot pot do izvožene datoteke (video datoteka ki jo proizvede koder) v &lt;b&gt;ukazni vrstici&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="obsolete">Aktivno</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="+382"/>
        <source>Name</source>
        <translation type="unfinished">Ime</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Description</source>
        <translation type="unfinished">Opis</translation>
    </message>
    <message>
        <location line="-299"/>
        <location line="+302"/>
        <source>&amp;Add</source>
        <translation type="unfinished">&amp;Dodaj</translation>
    </message>
    <message>
        <location line="-298"/>
        <location line="+299"/>
        <source>&amp;Remove</source>
        <translation type="unfinished">&amp;Odstrani</translation>
    </message>
    <message>
        <location line="-296"/>
        <location line="+297"/>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Uredi</translation>
    </message>
    <message>
        <location line="-293"/>
        <source>Encoder settings</source>
        <translation type="unfinished">Nastavitve kodirnika</translation>
    </message>
    <message>
        <location line="+10"/>
        <location line="+286"/>
        <source>Do you want to be asked for an output file every time you choose to export?</source>
        <translation type="unfinished">Želite biti vprašani o izhodni datoteki vsakič, ko se odločite za izvažanje?</translation>
    </message>
    <message>
        <location line="-284"/>
        <location line="+286"/>
        <source>Yes</source>
        <translation type="unfinished">Da</translation>
    </message>
    <message>
        <location line="-281"/>
        <location line="+282"/>
        <source>No</source>
        <translation type="unfinished">Ne</translation>
    </message>
    <message>
        <location line="-277"/>
        <location line="+278"/>
        <source>Set default output file:</source>
        <translation type="unfinished">Nastavi defoltno izvozno datoteko:</translation>
    </message>
    <message>
        <location line="-272"/>
        <location line="+273"/>
        <source>Browse</source>
        <translation type="unfinished">Brskaj</translation>
    </message>
    <message>
        <location line="-268"/>
        <location line="+269"/>
        <source>Start encoder:</source>
        <translation type="unfinished">Zaženi kodirnik:</translation>
    </message>
    <message>
        <location line="-264"/>
        <location line="+265"/>
        <source>Stop encoder:</source>
        <translation type="unfinished">Zaustavi kodirnik:</translation>
    </message>
    <message>
        <location line="-36"/>
        <source>Choose output file</source>
        <translation type="unfinished">Izberi datoteko za izvoz</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Below you can set which program/process Stopmotion should use for encoding the currently active project to a video file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>You should always use &lt;b&gt;$IMAGEPATH&lt;/b&gt; and &lt;b&gt;$VIDEOFILE&lt;/b&gt; to represent the image path and the video file, respectively.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>You can use &lt;b&gt;$FRAMERATE&lt;/b&gt; to represent the frame rate currently in use in the project.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Example with mencoder (jpeg images to mpeg4 video):</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExternalCommand</name>
    <message>
        <location filename="../src/application/externalcommand.cpp" line="+44"/>
        <source>Input to program:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Submit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Output from external command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+42"/>
        <location line="+3"/>
        <source>Result</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-3"/>
        <source>Failed!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Successful!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileDialog</name>
    <message>
        <source>Go to home directory</source>
        <translation type="obsolete">Pojdi v domači direktorij</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.ui" line="+32"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FrameBar</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framebar/framebar.cpp" line="+194"/>
        <source>Frame number: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FramePreferencesMenu</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framepreferencesmenu.cpp" line="+114"/>
        <source>Add &amp;sound</source>
        <translation type="unfinished">Dodaj &amp;zvok</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Remove Sound</source>
        <translation type="unfinished">&amp;Odstrani zvok</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Change name</source>
        <translation type="unfinished">Spremeni ime</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Sounds:</source>
        <translation type="unfinished">Zvoki:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&lt;h4&gt;Add sound&lt;/h4&gt; &lt;p&gt;With this button you can &lt;em&gt;add sounds&lt;/em&gt; to the selected frame.&lt;/p&gt; &lt;p&gt;The sound will begin playing when this frame is shown and play until it is done.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Dodaj zvok&lt;/h4&gt; &lt;p&gt;S tem gumbom lahko &lt;em&gt;dodajate zvoke&lt;/em&gt; izbranim okvirčkom.&lt;/p&gt; &lt;p&gt;Zvok bo začel igrati, ko se pojavi ta sličica in odigral vso svojo dolžino.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&lt;h4&gt;Remove sound&lt;/h4&gt; &lt;p&gt;With this button you can &lt;em&gt;remove&lt;/em&gt; the selected sound from this frame.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Odstrani zvok&lt;/h4&gt; &lt;p&gt;S tem gumbom lahko &lt;em&gt;odstranite&lt;/em&gt; izbrane zvoke s te sličice.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&lt;h4&gt;Change name&lt;/h4&gt; &lt;p&gt;With this button you can change the name of the selected sound. &lt;BR&gt;The name of the sound has no other effect than making it easier work with the animation.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Spremeni ime&lt;/h4&gt; &lt;p&gt;S tem gumbom lahko spremenite ime izbranega zvoka. &lt;BR&gt;Ime zvoka le olajša delo z animacijo.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&lt;h4&gt;Sounds&lt;/h4&gt; &lt;p&gt;This lists shows all the sounds connected to this frame.&lt;/p&gt;&lt;p&gt;The sounds will begin playing when this frame is shown and play until they are done.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Zvoki&lt;/h4&gt; &lt;p&gt;Ta seznam prikazuje vse zvoke povezane s to sličico.&lt;/p&gt;&lt;p&gt;Zvok se bo začel predvajati ko se bo pokazala ta sličica.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>FrameView</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="+290"/>
        <location line="+14"/>
        <location line="+13"/>
        <location line="+25"/>
        <location line="+18"/>
        <location line="+12"/>
        <source>Warning</source>
        <translation type="unfinished">Opozorilo</translation>
    </message>
    <message>
        <location line="-30"/>
        <location line="+18"/>
        <source>Grabbing failed. This may happen if you try
to grab from an invalid device. Please check
your grabber settings in the preferences menu.</source>
        <translation type="unfinished">Zajemanje ni uspelo. To se lahko zgodi če poskušate(new line)
zajemati iz neveljavne naprave. Prosim preverite(new line)
nastavitve zajemalnika v meniju za nastavitve.</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>You have to define an image grabber to use.
This can be set in the preferences menu.</source>
        <translation type="unfinished">Definirati morate napravo za zajemanje.(new line)
To lahko storite v nastavitvenem meniju.</translation>
    </message>
    <message>
        <location line="-68"/>
        <source>Pre poll command does not exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>You do not have the given grabber installed on your system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-27"/>
        <source>No video device selected in the preferences menu.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HelpWindow</name>
    <message>
        <source>&amp;New Window</source>
        <translation type="obsolete">&amp;Novo okno</translation>
    </message>
    <message>
        <source>&amp;Open File</source>
        <translation type="obsolete">&amp;Odpri datoteko</translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation type="obsolete">&amp;Natisni</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">&amp;Zapri</translation>
    </message>
    <message>
        <source>&amp;Backward</source>
        <translation type="obsolete">&amp;Nazaj</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="obsolete">&amp;Naprej</translation>
    </message>
    <message>
        <source>&amp;Home</source>
        <translation type="obsolete">&amp;Domov</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation type="obsolete">Dodaj med zaznamke</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="obsolete">&amp;Datoteka</translation>
    </message>
    <message>
        <source>&amp;Go</source>
        <translation type="obsolete">&amp;Pojdi</translation>
    </message>
    <message>
        <source>History</source>
        <translation type="obsolete">Zgodovina</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation type="obsolete">Zaznamki</translation>
    </message>
    <message>
        <source>Backward</source>
        <translation type="obsolete">Nazaj</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation type="obsolete">Naprej</translation>
    </message>
    <message>
        <source>Home</source>
        <translation type="obsolete">Domov</translation>
    </message>
</context>
<context>
    <name>ImportTab</name>
    <message>
        <source>&lt;p&gt;Below you can set which program/process stopmotion should use for grabbing images from the webcam, and displaying video.&lt;br&gt; &lt;br&gt; &lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;Spodaj lahko nastavite kateri program/proces naj stopmotion uporabi za zajemanje slik in prikaz videa&lt;br&gt; &lt;br&gt; &lt;/p&gt;</translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="obsolete">Aktivno</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="+67"/>
        <location line="+254"/>
        <source>Name</source>
        <translation type="unfinished">Ime</translation>
    </message>
    <message>
        <location line="-254"/>
        <location line="+254"/>
        <source>Description</source>
        <translation type="unfinished">Opis</translation>
    </message>
    <message>
        <location line="-238"/>
        <location line="+241"/>
        <source>&amp;Add</source>
        <translation type="unfinished">&amp;Dodaj</translation>
    </message>
    <message>
        <location line="-237"/>
        <location line="+238"/>
        <source>&amp;Remove</source>
        <translation type="unfinished">&amp;Odstrani</translation>
    </message>
    <message>
        <location line="-235"/>
        <location line="+236"/>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Uredi</translation>
    </message>
    <message>
        <location line="-232"/>
        <location line="+234"/>
        <source>Import device settings</source>
        <translation type="unfinished">Nastavitve uvozne naprave</translation>
    </message>
    <message>
        <location line="-225"/>
        <location line="+226"/>
        <source>Pre-poll command</source>
        <translation type="unfinished">Ukaz za zajemanje</translation>
    </message>
    <message>
        <location line="-219"/>
        <location line="+220"/>
        <source>Start daemon</source>
        <translation type="unfinished">Začni daemon</translation>
    </message>
    <message>
        <location line="-213"/>
        <location line="+214"/>
        <source>Stop daemon</source>
        <translation type="unfinished">Ustavi daemon</translation>
    </message>
    <message>
        <location line="-272"/>
        <location line="+256"/>
        <source>Below you can set which program/process Stopmotion should use for grabbing images from the selected device.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-254"/>
        <location line="+256"/>
        <source>You should always use &lt;b&gt;$VIDEODEVICE&lt;/b&gt; and &lt;b&gt;$IMAGEFILE&lt;/b&gt; to represent the video device and the image file, respectively.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LanguageHandler</name>
    <message>
        <location filename="../src/application/languagehandler.cpp" line="+87"/>
        <source>English</source>
        <translation type="unfinished">Angleško</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>English</source>
        <comment>This should be translated to the name of the language you are translating to, in that language. Example: English = Deutsch (Deutsch is &quot;German&quot; in German)</comment>
        <translation type="unfinished">Slovensko</translation>
    </message>
    <message>
        <location line="-16"/>
        <source>&amp;Translation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/helpbrowser.ui" line="+16"/>
        <source>Stopmotion Help Browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Backward</source>
        <translation type="unfinished">Nazaj</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Forward</source>
        <translation type="unfinished">Naprej</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindowGUI</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="+153"/>
        <source>Ready to rumble ;-)</source>
        <translation type="unfinished">Pripravjen na špas ;-)</translation>
    </message>
    <message>
        <location line="+350"/>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Novo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Open</source>
        <translation type="unfinished">&amp;Odpri</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+279"/>
        <source>&amp;Save</source>
        <translation type="unfinished">&amp;Shrani</translation>
    </message>
    <message>
        <location line="-278"/>
        <source>Save &amp;As</source>
        <translation type="unfinished">Shrani &amp;kot</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Video</source>
        <translation type="unfinished">Video</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cinelerra</source>
        <translation type="unfinished">Cinelerra</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Quit</source>
        <translation type="unfinished">&amp;Izhod</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Undo</source>
        <translation type="unfinished">&amp;Razveljavi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Re&amp;do</source>
        <translation type="unfinished">&amp;Uveljavi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cu&amp;t</source>
        <translation type="unfinished">&amp;Izreži</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;Kopiraj</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Paste</source>
        <translation type="unfinished">&amp;Prilepi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Go to frame</source>
        <translation type="unfinished">&amp;Pojdi na sličico</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Configure Stopmotion</source>
        <translation type="unfinished">&amp;Nastavi Stopmotion</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>What&apos;s &amp;This</source>
        <translation type="unfinished">Kaj &amp;je &amp;to</translation>
    </message>
    <message>
        <location line="-119"/>
        <location line="+120"/>
        <location line="+47"/>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Pomoč</translation>
    </message>
    <message>
        <location line="-46"/>
        <source>&amp;About</source>
        <translation type="unfinished">&amp;O</translation>
    </message>
    <message>
        <source>Frame number: 0</source>
        <translation type="obsolete">Številka sličice: 0</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Go to frame:</source>
        <translation type="unfinished">Pojdi na sličico:</translation>
    </message>
    <message>
        <location line="-150"/>
        <location line="+160"/>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Datoteka</translation>
    </message>
    <message>
        <location line="-158"/>
        <location line="+772"/>
        <source>Open &amp;Recent</source>
        <translation type="unfinished">Odpri &amp;Nedavno</translation>
    </message>
    <message>
        <location line="-773"/>
        <location line="+172"/>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Izvozi</translation>
    </message>
    <message>
        <location line="-169"/>
        <location line="+185"/>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Uredi</translation>
    </message>
    <message>
        <location line="-168"/>
        <location line="+163"/>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;Nastavitve</translation>
    </message>
    <message>
        <source>&amp;Languages</source>
        <translation type="obsolete">&amp;Jeziki</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&lt;h4&gt;New&lt;/h4&gt; &lt;p&gt;Creates a &lt;em&gt;new&lt;/em&gt; project.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Novo&lt;/h4&gt; &lt;p&gt;Ustvari &lt;em&gt;nov&lt;/em&gt; projekt.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>New project</source>
        <translation type="unfinished">Nov projekt</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&lt;h4&gt;Open&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Opens&lt;/em&gt; a Stopmotion project file.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Odpri&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Odpre&lt;/em&gt; obstoječi Stopmotion projekt.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Open project</source>
        <translation type="unfinished">Odpri projekt</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&lt;h4&gt;Save&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a Stopmotion project file. &lt;BR&gt;If this project has been saved before it will automatically be saved to the previously selected file.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Shrani&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Shrani&lt;/em&gt; trenutno izbrano animacijo kot Stopmotion projekt. &lt;BR&gt;Če je bil ta projekt že prej shranjen bo avtomatsko shranjen v prejšnjo datoteko.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Save project</source>
        <translation type="unfinished">Shrani projekt</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&lt;h4&gt;Save As&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a Stopmotion project file.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Shrani kot&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Shrani&lt;/em&gt; .&lt;/p&gt;trenutno izbrano animacijo kot Stopmotion projekt.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Save project As</source>
        <translation type="unfinished">Shrani projekt kot</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&lt;h4&gt;Video&lt;/h4&gt; &lt;p&gt;Exports the current project as &lt;em&gt;video&lt;/em&gt;.&lt;/p&gt;You will be given a wizard to guide you.</source>
        <translation type="unfinished">&lt;h4&gt;Video&lt;/h4&gt; &lt;p&gt;Izvozi trenutno izbrani projekt kot &lt;em&gt;video&lt;/em&gt;.&lt;/p&gt;Pri tem vas bo vodil čarovnik.</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&lt;h4&gt;Cinerella&lt;/h4&gt; &lt;p&gt;Exports the current animation as a &lt;em&gt;Cinerella&lt;/em&gt; project.&lt;/p&gt;You will be given a wizard to guide you.</source>
        <translation type="unfinished">&lt;h4&gt;Cinerella&lt;/h4&gt; &lt;p&gt;Izvozi trenutno izbrano animacijo kot &lt;em&gt;Cinerella&lt;/em&gt; projekt.&lt;/p&gt;Pri tem vas bo vodil čarovnik.</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&lt;h4&gt;Quit&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Quits&lt;/em&gt; the program.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Izhod&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Zapre&lt;/em&gt; program.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Quit</source>
        <translation type="unfinished">Izhod</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&lt;h4&gt;Undo&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Undoes&lt;/em&gt; your last operation. You can press undo several time to undo earlier operations.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Razveljavi&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Razveljavi&lt;/em&gt; vaše zadnje dejanje. Z večkratnim pritiskanjem razveljavite razveljavite več prejšnjih dejanj.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Undo</source>
        <translation type="unfinished">Razveljavi</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&lt;h4&gt;Redo&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Redoes&lt;/em&gt; your last operation. You can press redo several times to redo several operations.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Uveljavi&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Uveljavi&lt;/em&gt; razveljavljeno dejanje. Z večkratnim pritiskanjem uveljavite več razveljavljenih dejanj.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Redo</source>
        <translation type="unfinished">Uveljavi</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&lt;h4&gt;Cut&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Cuts&lt;/em&gt; the selected frames out of the animation and adds them to the clipboard so that you can paste them in somewhere else.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Izreži&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Izreže&lt;/em&gt; izbrane sličice iz animacije in jih doda v odlagališče da jih lahko prilepite drugam.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Cut</source>
        <translation type="unfinished">Izreži</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&lt;h4&gt;Copy&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Copies&lt;/em&gt; the selected frames to the clipboard. You can then paste them in another place.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Kopiraj&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Skopira&lt;/em&gt; izbrane sličice iz animacije in jih doda v odlagališče da jih lahko prilepite drugam.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Copy</source>
        <translation type="unfinished">Kopiraj</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&lt;h4&gt;Paste&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Pastes&lt;/em&gt; the frames which are currently in the clipboard into the selected location.&lt;/p&gt; &lt;p&gt;You can copy/cut images from another programs and then use this option to paste them into this animation.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Prilepi&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Prilepi&lt;/em&gt; sličice, ki so trenutno v odladališču v izbrano mesto.&lt;/p&gt; &lt;p&gt;Lahko kopirate ali izrežete sličice iz drugih programov in jih z uporabo tega ukaza prilepite v trenutno izbrano animacijo.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Paste</source>
        <translation type="unfinished">Prilepi</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&lt;h4&gt;Go to frame&lt;/h4&gt; &lt;p&gt;This will bring up a popup-menu at the bottom where you can choose a frame you want to &lt;em&gt;go to&lt;/em&gt;.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Pojdi na sličico&lt;/h4&gt; &lt;p&gt;Spodaj se bo odprl se bo popup-meni kamor boste vpisali sličico na katero želite skočiti.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Go to frame</source>
        <translation type="unfinished">Pojdi na sličico</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&lt;h4&gt;Configure Stopmotion&lt;/h4&gt; &lt;p&gt;This will opens a window where you can &lt;em&gt;configure&lt;/em&gt; Stopmotion with various input and output devices.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Nastavi Stopmotion&lt;/h4&gt; &lt;p&gt;Odplo se vam bo okno v katerem lahko &lt;em&gt;nastavite&lt;/em&gt; Stopmotion z različnimi vhodnimi in izhodnimi napravami.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Configure Stopmotion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&lt;h4&gt;What&apos;s This&lt;/h4&gt; &lt;p&gt;This will give you a WhatsThis mouse cursor which can be used to bring up helpful information like this.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Kaj je to&lt;/h4&gt; &lt;p&gt;S tem omogočite KajJeTo kurzor, ki vam lahko izda kak koristen nasvet kot na primer tale.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>What&apos;s This</source>
        <translation type="unfinished">Kaj je to</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&lt;h4&gt;Help&lt;/h4&gt; &lt;p&gt;This button will bring up a dialog with the Stopmotion manual&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Pomoč&lt;/h4&gt; &lt;p&gt;S tem gumbom lahko pridete do priročnika za Stopmotion&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Help</source>
        <translation type="unfinished">Pomoč</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&lt;h4&gt;About&lt;/h4&gt; &lt;p&gt;This will display a small information box where you can read general information as well as the names of the developers behind this excellent piece of software.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;O&lt;/h4&gt; &lt;p&gt;Odpre novo okno, kjer si lahko preberete splošne podatke in imena razvijalcev tega enkratnega programa.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>About</source>
        <translation type="unfinished">O</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&lt;h4&gt;Frame number&lt;/h4&gt;&lt;p&gt;This area displays the numberof the currently selected frame&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Številka sličice&lt;/h4&gt;&lt;p&gt;Tu lahko vidite na kateri sličici se trenutno nahajate.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&lt;h4&gt;FrameView&lt;/h4&gt;&lt;p&gt; In this area you can see the selected frame. You can also play animations in this window by pressing the &lt;b&gt;Play&lt;/b&gt; button.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Ogledno okno&lt;/h4&gt;&lt;p&gt; Tu si lahko ogledate izbrano sličico. V tem oknu lahko tudi predvajate animacije s pritiskom na gumb &lt;b&gt;Predvajaj&lt;/b&gt;.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&lt;h4&gt;Go to frame menu&lt;/h4&gt; &lt;p&gt;Here you can specify a framenumber and the program will jump to the specified frame&lt;/p&gt; </source>
        <translation type="unfinished">&lt;h4&gt;Pojdi na sličico&lt;/h4&gt; &lt;p&gt;Tu lahko dolocite številko sličice na katero naj program preskoči&lt;/p&gt;(sp)</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&lt;h4&gt;Frame preferences menu&lt;/h4&gt; &lt;p&gt;In this menu you can set preferences for the selected frame/frames, such as &lt;b&gt;subtitles&lt;/b&gt;, &lt;b&gt;sound effects&lt;/b&gt;, etc.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Nastavitve sličice&lt;/h4&gt; &lt;p&gt;V tem meniju lahko spreminjate nastavitve za izbrano sličico/sličice, kot so &lt;b&gt;podnapisi&lt;/b&gt;, &lt;b&gt;zvočni efekti&lt;/b&gt;, itd.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&lt;h4&gt;Tool menu&lt;/h4&gt; &lt;p&gt;This is the tool menu where most of the buttons and widgets you will need when working on stop motion animations are located.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Orodni meni&lt;/h4&gt; &lt;p&gt;To je meni kjer je lociranih večino gumbov in funkcij, ki jih potrebujete pri delu s stop motion animacijami.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&lt;h4&gt;FrameBar&lt;/h4&gt; &lt;p&gt;In this area you can see the frames and scenes in the animations and build the animation by moving the them around.&lt;/p&gt;&lt;p&gt;You can switch to the next and the previous frame using the &lt;b&gt;arrow buttons&lt;/b&gt; or &lt;b&gt;x&lt;/b&gt; and &lt;b&gt;z&lt;/b&gt;&lt;/p&gt; </source>
        <translation type="unfinished">&lt;h4&gt;Sličična letev&lt;/h4&gt; &lt;p&gt;Tu lahko vidite sličice in scene v projektu in z njihovim razporejanjem lahko naredite animacijo.&lt;/p&gt;&lt;p&gt;Lahko preklapljate med prejšnjimi in sledečimi sličicami s pritiskanjem na &lt;b&gt;puščične tipke&lt;/b&gt; ali &lt;b&gt;x&lt;/b&gt; in &lt;b&gt;z&lt;/b&gt;tipke.&lt;/p&gt;(sp)</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Unsaved changes</source>
        <translation type="unfinished">Neshranjene spremembe</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>There are unsaved changes. Do you want to save?</source>
        <translation type="unfinished">Vse spremembe niso bile shranjene. Jih želite shraniti?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Do&amp;n&apos;t save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Abort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+132"/>
        <location line="+50"/>
        <source>&amp;Yes</source>
        <translation type="unfinished">&amp;Da</translation>
    </message>
    <message>
        <location line="-50"/>
        <location line="+50"/>
        <source>&amp;No</source>
        <translation type="unfinished">&amp;Ne</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation type="obsolete">Shrani datoteko</translation>
    </message>
    <message>
        <location line="-55"/>
        <location line="+52"/>
        <source>Warning</source>
        <translation type="unfinished">Opozorilo</translation>
    </message>
    <message>
        <location line="-51"/>
        <source>Cannot find any registered encoder to be used for
video export. This can be set in the preferences
menu. Export to video will not be possible until you
have set an encoder to use. Do you want to set it now?</source>
        <translation type="unfinished">Ne najdem nobenega registriranega kodirnika za(new line)
izvoz videa. To lahko nastavite v nastavitvenem(new line)
meniju. Izvoz videa ne bo mogoč dokrer ne nastavite(new line)
kateri kodirnik naj se uporablja. Ga želite nastaviti sedaj?</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Export to video file</source>
        <translation type="unfinished">Izvozi kot video datoteko</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>The registered encoder is not valid. Do you want
to check your settings in the preferences menu?</source>
        <translation type="unfinished">Registrirani kodirnik ni veljaven. Ali želite(new line)
preveriti vaše nastavitve v nastavitvenem meniju?</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Export to file</source>
        <translation type="unfinished">Izvozi kot datoteko</translation>
    </message>
    <message>
        <source>&lt;p&gt;This is the stopmotion application for creating stopmotion animations.&lt;/p&gt;&lt;p&gt;(c) 2005, Fredrik Berg Kjølstad and Bjørn Erik Nilsen&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;To je program stopmotion namenjen ustvarjanju stopmotion animacij.&lt;/p&gt;&lt;p&gt;(c) 2005, Fredrik Berg Kjølstad and Bjørn Erik Nilsen&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;Main developers&lt;/b&gt;&lt;br&gt;Fredrik Berg Kjølstad &amp;lt;fredrikbk@hotmail.com&amp;gt;&lt;br&gt;Bjørn Erik Nilsen &amp;lt;bjoern.nilsen@bjoernen.com&amp;gt;&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;&lt;b&gt;Glavna razvijalca&lt;/b&gt;&lt;br&gt;Fredrik Berg Kjølstad &amp;lt;fredrikbk@hotmail.com&amp;gt;&lt;br&gt;Bjørn Erik Nilsen &amp;lt;bjoern.nilsen@bjoernen.com&amp;gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <source>A&amp;uthors</source>
        <translation type="obsolete">&amp;Avtorji</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;Coordinating&lt;/b&gt;&lt;br&gt;Herman Robak &amp;lt;herman@skolelinux.no&amp;gt;&lt;br&gt;Øyvind Kolås &amp;lt;pippin@gimp.org&amp;gt;&lt;/p&gt;&lt;p&gt;&lt;b&gt;Testing&lt;/b&gt;&lt;br&gt;Tore Sinding Bekkedal &amp;lt;toresbe@ifi.uio.no&amp;gt;&lt;br&gt;Finn Arne Johansen &amp;lt;faj@bzz.no&amp;gt;&lt;br&gt;Halvor Borgen &amp;lt;halvor.borgen@hig.no&amp;gt;&lt;br&gt;Bjørn Are Hansen &amp;lt;post@bahansen.net&amp;gt;&lt;br&gt;John Steinar Bildøy &amp;lt;johnsbil@haldenfriskole.no&amp;gt;&lt;br&gt;Ole-Anders Andreassen &amp;lt;ole-anders.andreassen@sunndal.kommune.no&amp;gt;&lt;br&gt;&lt;/p&gt;&lt;p&gt;&lt;b&gt;Translation&lt;/b&gt;&lt;br&gt;George Helebrant &amp;lt;helb@skatekralovice.com&amp;gt; (Czech)&lt;br&gt;&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;&lt;b&gt;Koordinacija&lt;/b&gt;&lt;br&gt;Herman Robak &amp;lt;herman@skolelinux.no&amp;gt;&lt;br&gt;Øyvind Kolås &amp;lt;pippin@gimp.org&amp;gt;&lt;/p&gt;&lt;p&gt;&lt;b&gt;Testiranje&lt;/b&gt;&lt;br&gt;Tore Sinding Bekkedal &amp;lt;toresbe@ifi.uio.no&amp;gt;&lt;br&gt;Finn Arne Johansen &amp;lt;faj@bzz.no&amp;gt;&lt;br&gt;Halvor Borgen &amp;lt;halvor.borgen@hig.no&amp;gt;&lt;br&gt;Bjørn Are Hansen &amp;lt;post@bahansen.net&amp;gt;&lt;br&gt;John Steinar Bildøy &amp;lt;johnsbil@haldenfriskole.no&amp;gt;&lt;br&gt;Ole-Anders Andreassen &amp;lt;ole-anders.andreassen@sunndal.kommune.no&amp;gt;&lt;br&gt;&lt;/p&gt;&lt;p&gt;&lt;b&gt;Prevodi&lt;/b&gt;&lt;br&gt;George Helebrant &amp;lt;helb@skatekralovice.com&amp;gt; (Czech)&lt;br&gt;Gorazd Bizjak and Matej Lavrenčič&amp;lt;info@zapstudio.net&amp;gt; (Slovenian)&lt;br&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Thanks To</source>
        <translation type="obsolete">&amp;Zahvale gredo</translation>
    </message>
    <message>
        <source>&amp;Licence Agreement</source>
        <translation type="obsolete">&amp;Licenčna pogodba</translation>
    </message>
    <message>
        <source>Stopmotion User Manual</source>
        <translation type="obsolete">Stopmotion uporabniški priročnik</translation>
    </message>
    <message>
        <location line="-458"/>
        <source>Frame number: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+294"/>
        <source>Choose project file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+68"/>
        <source>Save As</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ModelHandler</name>
    <message>
        <location filename="../src/application/modelhandler.cpp" line="+58"/>
        <source>Choose frames to add</source>
        <translation type="unfinished">Izberi sličice, ki naj se dodajo</translation>
    </message>
    <message>
        <location line="+121"/>
        <source>Removed the selected frame</source>
        <translation type="unfinished">Odstrani izbrane sličice</translation>
    </message>
    <message>
        <location line="+37"/>
        <location line="+11"/>
        <location line="+17"/>
        <source>Warning</source>
        <translation type="unfinished">Opozorilo</translation>
    </message>
    <message>
        <location line="-27"/>
        <source>You do not have Gimp installed on your system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+11"/>
        <source>There is no active frame to open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Failed to start Gimp!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PreferencesMenu</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="+73"/>
        <location line="+46"/>
        <source>Video &amp;Import</source>
        <translation type="unfinished">Video &amp;Uvoz</translation>
    </message>
    <message>
        <location line="-37"/>
        <location line="+38"/>
        <source>Video &amp;Export</source>
        <translation type="unfinished">Video &amp;Izvoz</translation>
    </message>
    <message>
        <location line="-81"/>
        <location line="+75"/>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-71"/>
        <location line="+72"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-58"/>
        <location line="+59"/>
        <source>Preferences Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-25"/>
        <location line="+27"/>
        <source>Video &amp;Device</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtFrontend</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="+120"/>
        <source>Cancel</source>
        <translation type="unfinished">Prekliči</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation type="obsolete">Napredek</translation>
    </message>
    <message>
        <location line="+72"/>
        <location line="+15"/>
        <source>Warning</source>
        <translation type="unfinished">Opozorilo</translation>
    </message>
    <message>
        <location line="-11"/>
        <location line="+8"/>
        <source>Fatal</source>
        <translation type="unfinished">Usodno</translation>
    </message>
    <message>
        <location line="+207"/>
        <source>A newer version of the preferences file with few more default
values exists. Do you want to use this one? (Your old preferences
 will be saved in ~/.stopmotion/preferences.xml.OLD)</source>
        <translation type="unfinished">Novejša inačica nastavitvene datoteke z malo več defoltnih nastavitev(new line)
je izšla. Bi jo radi uporabljali? (Vaše stare nastavitve(new line)
bodo shranjene v ~/.stopmotion/preferences.xml.OLD)</translation>
    </message>
    <message>
        <source>vgrabbj VGA singleshot</source>
        <translation type="obsolete">vgrabbj VGA z enim posnetkom</translation>
    </message>
    <message>
        <location line="-310"/>
        <source>Please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Connecting camera...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Importing frames from disk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Exporting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Restoring project...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Saving scenes to disk...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+153"/>
        <source>vgrabbj</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>The simplest setting. Fairly slow</source>
        <translation type="unfinished">Najbolj preprosta nastavitev. Deluje počasi</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>vgrabbj VGA daemon</source>
        <translation type="unfinished">vgrabbj VGA prikriti proces</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Starts vgrabbj as a daemon. Pretty fast.</source>
        <translation type="unfinished">Zažene vgrabbj kot prikriti proces. Deluje hitro.</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>uvccapture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Grabbing from V4L2 devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Exports from jpeg images to mpeg1 video</source>
        <translation type="unfinished">Izvozi iz jpeg slik v mpeg1 video</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Exports from jpeg images to mpeg2 video</source>
        <translation type="unfinished">Izvozi iz jpeg slik v mpeg2 video</translation>
    </message>
    <message>
        <location line="+9"/>
        <location line="+9"/>
        <location line="+8"/>
        <source>Exports from jpeg images to mpeg4 video</source>
        <translation type="unfinished">Izvozi iz jpeg slik v mpeg4 video</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Stopmotion cannot be started; it seems like it is already running.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+50"/>
        <source>Question</source>
        <translation type="unfinished">Vprašanje</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation type="obsolete">&amp;Da</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation type="obsolete">&amp;Ne</translation>
    </message>
    <message>
        <location line="-112"/>
        <source>dvgrab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-9"/>
        <source>videodog singleshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Videodog.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Grabbing from DV-cam.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RunAnimationHandler</name>
    <message>
        <location filename="../src/application/runanimationhandler.cpp" line="+90"/>
        <source>Running animation</source>
        <translation type="unfinished">Animacija v teku</translation>
    </message>
</context>
<context>
    <name>SoundHandler</name>
    <message>
        <location filename="../src/application/soundhandler.cpp" line="+44"/>
        <source>Sounds (*.ogg)</source>
        <translation type="unfinished">Zvoki (*.ogg)</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Sound name</source>
        <translation type="unfinished">Ime zvoka</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Enter the name of the sound:</source>
        <translation type="unfinished">Vpiši ime zvoka:</translation>
    </message>
    <message>
        <location line="-27"/>
        <source>Choose sound file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ToolsMenu</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="+223"/>
        <source>FPS chooser</source>
        <translation type="unfinished">Izberi FPS</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Number of images:</source>
        <translation type="unfinished">Število slik:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mix</source>
        <translation type="unfinished">Zmešaj</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Diff</source>
        <translation type="unfinished">Razlika</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Playback</source>
        <translation type="unfinished">Predvajaj</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Per second</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Per minute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Per hour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&lt;h4&gt;Add Frames (CTRL+F)&lt;/h4&gt; &lt;p&gt;Click on this button to &lt;em&gt;add&lt;/em&gt; frames to the animation.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Dodaj Sličice (CTRL+F)&lt;/h4&gt; &lt;p&gt;Pritisni na ta gumb da &lt;em&gt;dodaš&lt;/em&gt; sličice tej animaciji.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&lt;h4&gt;Remove Selection (Delete)&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;remove&lt;/em&gt; the selected frames from the animation.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Zbriši izbrano (Delete)&lt;/h4&gt; &lt;p&gt;Pritisnite na ta gumb če želite &lt;em&gt;zbrisati&lt;/em&gt; izbrane sličice iz te animacije.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&lt;h4&gt;New Scene (CTRL+E)&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;create&lt;/em&gt; a new &lt;em&gt;scene&lt;/em&gt; to the animation.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Nova Scena (CTRL+E)&lt;/h4&gt; &lt;p&gt;Pritisnite ta gumb, če želite &lt;em&gt;ustvariti&lt;/em&gt; novo &lt;em&gt;sceno&lt;/em&gt; v tej animaciji.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&lt;h4&gt;Remove Scene (SHIFT+Delete)&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;remove&lt;/em&gt; the selected scene from the animation.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Odstrani sceno (SHIFT+Delete)&lt;/h4&gt; &lt;p&gt;Pritisnite na ta gumb da &lt;em&gt;odstranite&lt;/em&gt; izbrane scene iz te animation.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&lt;h4&gt;Toggle camera on/off (C)&lt;/h4&gt; &lt;p&gt;Click this button to toggle the camera on and off&lt;/p&gt; </source>
        <translation type="unfinished">&lt;h4&gt;Preklopi kamero vklop/izklop (C)&lt;/h4&gt; &lt;p&gt;Pritisnite na ta gumb da bi vklopili ali izklopili kamero&lt;/p&gt;(sp)</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&lt;h4&gt;Capture Frame (Space)&lt;/h4&gt; &lt;p&gt;Click on this button to &lt;em&gt;capture&lt;/em&gt; a frame from the camera an put it in the animation&lt;/p&gt; &lt;p&gt; This can also be done by pressing the &lt;b&gt;Space key&lt;/b&gt;&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Zajemi sličico (Space)&lt;/h4&gt; &lt;p&gt;Pritisnite sem za &lt;em&gt;zajemanje&lt;/em&gt; iz kamere v animacijo&lt;/p&gt; &lt;p&gt; To lahko storite tudi s priniskom na &lt;b&gt;preslednico&lt;/b&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&lt;h4&gt;Number of images&lt;/h4&gt; &lt;p&gt;By changing the value in this slidebar you can specify how many images backwards in the animation which should be mixed on top of the camera or if you are in playback mode: how many images to play. &lt;/p&gt; &lt;p&gt;By mixing the previous image(s) onto the camera you can more easily see how the next shot will be in relation to the other, thereby making a smoother stop motion animation!&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Število slik&lt;/h4&gt; &lt;p&gt;S spreminjanjem te vrednosti določite koliko slik nazaj v animaciji naj bo vidnih preko slike iz kamere in če ste v predvajalnem načinu; koliko sličic naj se predvaja. &lt;/p&gt; &lt;p&gt;Z gledanjem prejšnjih slik preko slike iz kamere lažje vidite kakšna bo naslednja sličica v odnosu na prejšnjo in s tem naredite gibanje v animaciji bolj gladko.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&lt;h4&gt;FPS chooser&lt;/h4&gt; &lt;p&gt;By changing the value in this chooser you set which speed the animation in the &lt;b&gt;FrameView&lt;/b&gt; should run at.&lt;/p&gt; &lt;p&gt;To start an animation press the &lt;b&gt;Run Animation&lt;/b&gt; button.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;izbiralec hitrosti predvajanja&lt;/h4&gt; &lt;p&gt;S spreminjanjem te vrednosti lahko določite hitrost predvajanja v &lt;b&gt;Predvajalnem oknu&lt;/b&gt;.&lt;/p&gt; &lt;p&gt;Za predvajanje animacije pritisnite gumb &lt;b&gt;Predvajaj animacijo&lt;/b&gt;.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&lt;h4&gt;Play animation (K, P)&lt;/h4&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Predvajaj animacijo (K, P)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&lt;h4&gt;Stop animation (K, P)&lt;/h4&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Ustavi animacijo (K, P)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&lt;h4&gt;Previous frame (J, Left)&lt;/h4&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Prejšnja sličica (J, Left)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&lt;h4&gt;Next frame (L, Right)&lt;/h4&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Naslednja sličica (L, Right)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&lt;h4&gt;Previous scene (I)&lt;/h4&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Prejšnja scena (I)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&lt;h4&gt;Next scene (O)&lt;/h4&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Naslednja scena (O)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&lt;h4&gt;Loop animation (CTRL+L)&lt;/h4&gt; &lt;p&gt;With this button you can set whether you want the animation to play to the end, or to loop indefinetly.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;h4&gt;Loop animation (CTRL+L)&lt;/h4&gt; &lt;p&gt;With this button you can set whether you want the animation to play to the end, or to loop indefinetly.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+85"/>
        <source>Notice</source>
        <translation type="unfinished">Obvestilo</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Playback only currently works when running the grabber 
as a daemon. Go to the preferences menu (CTRL+P) to switch 
to running the image grabbing as a daemon.</source>
        <translation type="unfinished">Prodvajanje trenutno deluje le ko je  (new line)
as a daemon. Go to the preferences menu (CTRL+P) to switch (new line)
to running the image grabbing as a daemon.</translation>
    </message>
    <message>
        <location line="-185"/>
        <source>Auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+45"/>
        <source>&lt;h4&gt;Launch Gimp&lt;/h4&gt; &lt;p&gt;Click this button to open the active frame in Gimp&lt;/p&gt; &lt;p&gt;Note that you can also drag images from the frame bar and drop them on Gimp&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
